@@ -4,9 +4,9 @@ Sentinel interpreter for jac code in AST form
 This interpreter should be inhereted from the class that manages state
 referenced through self.
 """
-from jaseci.graph.node import Node
-from jaseci.graph.edge import Edge
-from jaseci.actor.walker import Walker
+from jaseci.prim.node import Node
+from jaseci.prim.edge import Edge
+from jaseci.prim.walker import Walker
 from jaseci.jac.interpreter.interp import Interp
 from jaseci.jac.machine.jac_scope import JacScope
 
