@@ -650,6 +650,36 @@ async walker simple_async_with_sync {
 }
 """
 
+async_syntax_with_update = """
+node a {
+    has value = false;
+}
+walker init {
+    root {
+        spawn here ++> node::a;
+    }
+}
+
+async walker update_value {
+    root {
+        take --> node::a;
+    }
+    a {
+        here.value = true;
+        report here.context;
+    }
+}
+
+walker get_value {
+    root {
+        take --> node::a;
+    }
+    a {
+        report here.context;
+    }
+}
+"""
+
 block_scope_check = """
     walker init {
         i=5;
@@ -692,3 +722,27 @@ async walker b {
     }
 }
 """
+
+walker_null_args = """
+node c {
+    has c1, c2;
+}
+
+walker b {
+    has anchor b1, b2;
+    with entry {
+        report b1;
+        report b2;
+    }
+}
+
+walker a {
+    has a1;
+
+    with entry {
+        a2 = null;
+        te = spawn here walker::b(b1 = a1, b2 = a2);
+        te = spawn here ++> node::c(c1=a1, c2=a2);
+    }
+}
+"""
